% method of class @signal
% function sig=buildfrompoints(sig,xx,yy)
% calculates a @signal from the points in x and y 
%
%   INPUT VALUES:
%       sig:  original @signal
%       xx: x-values of points
%       yy: y-values of points
%    
%   RETURN VALUE:
%       sig: new @signal 
%
% (c) 2003-2008, University of Cambridge, Medical Research Council 
% Maintained by Tom Walters (tcw24@cam.ac.uk), written by Stefan Bleeck (stefan@bleeck.de)
% http://www.pdn.cam.ac.uk/cnbh/aim2006
% $Date: 2008-06-10 18:00:16 +0100 (Tue, 10 Jun 2008) $
% $Revision: 585 $

function sig=buildfrompoints(sig,xx,yy)


x1=1;
y1=0;

sig=mute(sig);

nr_points=length(xx);
for i=1:nr_points
    x2=round(time2bin(sig,xx(i)));
    y2=yy(i);

    line=linspace(y1,y2,x2-x1+1);
    sig=setvalues(sig,line,x1);

    x1=x2+1;
    y1=y2;
    
end


